[PATCH] ceph: [PATCH] ceph: use list_move_tail instead of list_del/list_add_tail

Subsystems: ceph common code (libceph), the rest

STALE5095d

2 messages, 2 authors, 2012-09-05 · open the first message on its own page

[PATCH] ceph: [PATCH] ceph: use list_move_tail instead of list_del/list_add_tail

From: Wei Yongjun <hidden>
Date: 2012-09-05 06:34:32

From: Wei Yongjun <redacted>

Using list_move_tail() instead of list_del() + list_add_tail().

Signed-off-by: Wei Yongjun <redacted>
---
 net/ceph/pagelist.c | 5 ++---
 1 file changed, 2 insertions(+), 3 deletions(-)
diff --git a/net/ceph/pagelist.c b/net/ceph/pagelist.c
index 665cd23..92866be 100644
--- a/net/ceph/pagelist.c
+++ b/net/ceph/pagelist.c
@@ -1,4 +1,3 @@
-
 #include <linux/module.h>
 #include <linux/gfp.h>
 #include <linux/pagemap.h>
@@ -134,8 +133,8 @@ int ceph_pagelist_truncate(struct ceph_pagelist *pl,
 	ceph_pagelist_unmap_tail(pl);
 	while (pl->head.prev != c->page_lru) {
 		page = list_entry(pl->head.prev, struct page, lru);
-		list_del(&page->lru);                /* remove from pagelist */
-		list_add_tail(&page->lru, &pl->free_list); /* add to reserve */
+		/* move from pagelist to reserve */
+		list_move_tail(&page->lru, &pl->free_list);
 		++pl->num_pages_free;
 	}
 	pl->room = c->room;

Re: [PATCH] ceph: [PATCH] ceph: use list_move_tail instead of list_del/list_add_tail

From: Sage Weil <hidden>
Date: 2012-09-05 15:48:31

Applied to the ceph queue. Thanks!
sage


On Wed, 5 Sep 2012, Wei Yongjun wrote:
quoted hunk
From: Wei Yongjun <redacted>

Using list_move_tail() instead of list_del() + list_add_tail().

Signed-off-by: Wei Yongjun <redacted>
---
 net/ceph/pagelist.c | 5 ++---
 1 file changed, 2 insertions(+), 3 deletions(-)
diff --git a/net/ceph/pagelist.c b/net/ceph/pagelist.c
index 665cd23..92866be 100644
--- a/net/ceph/pagelist.c
+++ b/net/ceph/pagelist.c
@@ -1,4 +1,3 @@
-
 #include <linux/module.h>
 #include <linux/gfp.h>
 #include <linux/pagemap.h>
@@ -134,8 +133,8 @@ int ceph_pagelist_truncate(struct ceph_pagelist *pl,
 	ceph_pagelist_unmap_tail(pl);
 	while (pl->head.prev != c->page_lru) {
 		page = list_entry(pl->head.prev, struct page, lru);
-		list_del(&page->lru);                /* remove from pagelist */
-		list_add_tail(&page->lru, &pl->free_list); /* add to reserve */
+		/* move from pagelist to reserve */
+		list_move_tail(&page->lru, &pl->free_list);
 		++pl->num_pages_free;
 	}
 	pl->room = c->room;
Keyboard shortcuts
hback out one level
jnext message in thread
kprevious message in thread
ldrill in
Escclose help / fold thread tree
?toggle this help